/*
 * Automatic channel selector for ieee802.11 A, B and G modes.
 *
 * Copyright (c) 2005 by Wilibox (www.wilibox.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#include <stdio.h>
#include <stdlib.h>

#include "selector.h"
#include "logger.h"

/* Maximum allowed channels count */
static const int MAX_CHANNELS_ALLOWED = QUAL_DATA_SIZE;


static int run(const int argc, char* argv[])
{
    int* channels = NULL;
    char* iface = NULL;
    int count = 0;
    int rv = 0;
    int i;

    /* Get interface */
    iface = argv[1];

    /* Allocate channels */
    channels = (int*)malloc(MAX_CHANNELS_ALLOWED * sizeof(int));
    if (!channels)
    {
        error_errno("malloc failed.\n");
        exit(0);
    }

    /* Fill channels array */
    for (i = 2;  i < argc; i++)
    {
        int ch = atoi(argv[i]);

        debug("Allowed channels[%d]=%d\n", count, ch);

        channels[count] = ch;
        count++;

        /* Do not allow buffer overflow */
        if (count >= MAX_CHANNELS_ALLOWED)
            break;
    }

    rv = get_best_channel(iface, count, channels);
    free(channels);

    return rv;
}

static void usage(void)
{
    printf("Usage: autochannel INTERFACE CHANNELS\n");
    printf("\tINTERFACE - wireless card interface;\n");
    printf("\tCHANNELS  - allowed channels list (space separated).\n");
}

int main(int argc, char* argv[])
{
    if (argc < 3)
    {
        usage();
        return 0;
    }

    return run(argc, argv);
}

